==> rust-reflink-copy_0.1.23.orig.tar.gz: reflink-copy-0.1.23/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.23](https://github.com/cargo-bins/reflink-copy/compare/v0.1.22...v0.1.23) - 2025-01-18

### Other

- Implement reflink_block for lunix ([#93](https://github.com/cargo-bins/reflink-copy/pull/93))

## [0.1.22](https://github.com/cargo-bins/reflink-copy/compare/v0.1.21...v0.1.22) - 2025-01-11

### Other

- Add reflink_block function ([#85](https://github.com/cargo-bins/reflink-copy/pull/85))

## [0.1.21](https://github.com/cargo-bins/reflink-copy/compare/v0.1.20...v0.1.21) - 2025-01-08

### Other

- Bump windows from 0.58.0 to 0.59.0 ([#90](https://github.com/cargo-bins/reflink-copy/pull/90))

## [0.1.20](https://github.com/cargo-bins/reflink-copy/compare/v0.1.19...v0.1.20) - 2024-11-10

### Other

- Implement check_reflink_support for windows ([#83](https://github.com/cargo-bins/reflink-copy/pull/83))
- Fail reflink_or_copy if target file already exist ([#81](https://github.com/cargo-bins/reflink-copy/pull/81))
- Bump tempfile from 3.8.0 to 3.12.0 ([#77](https://github.com/cargo-bins/reflink-copy/pull/77))

## [0.1.19](https://github.com/cargo-bins/reflink-copy/compare/v0.1.18...v0.1.19) - 2024-07-04

### Other
- Bump windows from 0.57.0 to 0.58.0 ([#74](https://github.com/cargo-bins/reflink-copy/pull/74))
- Use release-plz in publish.yml ([#72](https://github.com/cargo-bins/reflink-copy/pull/72))

==> rust-reflink-copy_0.1.26.orig.tar.gz: reflink-copy-0.1.26/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.26](https://github.com/cargo-bins/reflink-copy/compare/v0.1.25...v0.1.26) - 2025-03-19

### Other

- Bump windows from 0.60.0 to 0.61.0 ([#106](https://github.com/cargo-bins/reflink-copy/pull/106))

## [0.1.25](https://github.com/cargo-bins/reflink-copy/compare/v0.1.24...v0.1.25) - 2025-03-08

### Other

- Bump rustix from 0.38.34 to 1.0.1 ([#101](https://github.com/cargo-bins/reflink-copy/pull/101))

## [0.1.24](https://github.com/cargo-bins/reflink-copy/compare/v0.1.23...v0.1.24) - 2025-02-25

### Other

- Bump windows from 0.59.0 to 0.60.0 ([#98](https://github.com/cargo-bins/reflink-copy/pull/98))

## [0.1.23](https://github.com/cargo-bins/reflink-copy/compare/v0.1.22...v0.1.23) - 2025-01-18

### Other

- Implement reflink_block for lunix ([#93](https://github.com/cargo-bins/reflink-copy/pull/93))

## [0.1.22](https://github.com/cargo-bins/reflink-copy/compare/v0.1.21...v0.1.22) - 2025-01-11

### Other

- Add reflink_block function ([#85](https://github.com/cargo-bins/reflink-copy/pull/85))

## [0.1.21](https://github.com/cargo-bins/reflink-copy/compare/v0.1.20...v0.1.21) - 2025-01-08

### Other

- Bump windows from 0.58.0 to 0.59.0 ([#90](https://github.com/cargo-bins/reflink-copy/pull/90))

## [0.1.20](https://github.com/cargo-bins/reflink-copy/compare/v0.1.19...v0.1.20) - 2024-11-10

### Other

- Implement check_reflink_support for windows ([#83](https://github.com/cargo-bins/reflink-copy/pull/83))
- Fail reflink_or_copy if target file already exist ([#81](https://github.com/cargo-bins/reflink-copy/pull/81))
- Bump tempfile from 3.8.0 to 3.12.0 ([#77](https://github.com/cargo-bins/reflink-copy/pull/77))

## [0.1.19](https://github.com/cargo-bins/reflink-copy/compare/v0.1.18...v0.1.19) - 2024-07-04

### Other
- Bump windows from 0.57.0 to 0.58.0 ([#74](https://github.com/cargo-bins/reflink-copy/pull/74))
- Use release-plz in publish.yml ([#72](https://github.com/cargo-bins/reflink-copy/pull/72))
